/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.deploy.api.deployable;

import java.net.URL;
import java.util.List;

import org.ow2.util.ee.deploy.api.deployment.ear.IEARInfo;

/**
 * Represents an EAR deployable.
 * @author Florent Benoit
 */
public interface EARDeployable extends IDeployable<EARDeployable> {

    /**
     * @return the list of the EJB deployables for this EAR.
     */
    List<EJBDeployable<?>> getEJBDeployables();

    /**
     * @return the list of the EJB 2.1 deployables for this EAR.
     */
    List<EJB21Deployable> getEJB21Deployables();

    /**
     * @return the list of the EJB 3 deployables for this EAR.
     */
    List<EJB3Deployable> getEJB3Deployables();

    /**
     * @return the list of the War deployables for this EAR.
     */
    List<WARDeployable> getWARDeployables();

    /**
     * @return the list of the Rar deployables for this EAR.
     */
    List<RARDeployable> getRARDeployables();

    /**
     * @return the list of the Car deployables for this EAR.
     */
    List<CARDeployable> getCARDeployables();

    /**
     * @return the list of the Library deployables for this EAR.
     */
    List<LibDeployable> getLibDeployables();

    /**
     * @return the list of the deployables for this EAR.
     */
    List<IDeployable<?>> getAllDeployables();

    /**
     * @return EAR information (of the application.xml file).
     */
    IEARInfo getEARInfo();

    /**
     * @param url  of the wanted deployable
     * @return deployable corresponding to the url
     */
    IDeployable<?> getDeployable(URL url);

    /**
     * @param deployable a module of the EAR
     * @return url of the altDD if present or null if not
     */
    URL getAltDDURL(final IDeployable<?> deployable);

}
