/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.ow2.util.ee.deploy.api.deployable;

import org.ow2.util.ee.deploy.api.deployable.IDeployable;

/**
 * Interface for deployables built upon a single file that is not
 * a JAR file.
 * @author mleduque
 * @param <T> the type of the deployable.
 * @param <U> the type of the attached data.
 */
public interface FileDeployable<T extends IDeployable<T>, U> extends IDeployable<T> {

    /**
     * Gets the data attached to this deployable.
     * @return the attached data
     */
    public U getAttachedData();

    /**
     * Sets the data attached to this deployable.
     * @param attachedData the new attached data.
     */
    public void setAttachedData(final U attachedData);
}
