/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.deploy.api.deployable;

/**
 * Represents an OSGi deployable.
 * @author Florent Benoit
 */
public interface OSGiDeployable extends IDeployable<OSGiDeployable> {
    /**
     * Set if the bundle must be started or not.
     * @param start The value to set
     */
    void setStart(final Boolean start);

    /**
     * Return true if the bundle must be started, false otherwise.
     * @return True if the bundle must be started, false otherwise
     */
    Boolean isStart();

    /**
     * Set if the bundle must be a referenced JAR file.
     * @param reference The value to set
     */
    void setReference(final Boolean reference);

    /**
     * Return true if the bundle must be a referenced JAR file.
     * @return True if the bundle must be a referenced JAR file
     */
    Boolean isReference();

    /**
     * Set the bundle start level.
     * @param startLevel The value to set
     */
    void setStartLevel(final Integer startLevel);

    /**
     * Return the bundle start level value.
     * @return The bundle start level value
     */
    Integer getStartLevel();

    /**
     * Set if the bundle start operation is transient.
     * If true, the persistent autostart setting of the bundle is not modified.
     * @param startTransient The value to set
     */
    void setStartTransient(final Boolean startTransient);

    /**
     * Return true if the bundle start operation is transient.
     * @return True if the bundle start operation is transient
     */
    Boolean isStartTransient();

}
