/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.ow2.util.ee.deploy.api.deployable.factory;

import org.ow2.util.archive.api.IFileArchive;
import org.ow2.util.ee.deploy.api.deployable.FileDeployable;

/**
 * Base interface for FileDeployable factories.
 * @author mleduque
 */
public interface IFileDeployableFactory {
    /**
     * Creates and returns a FileDeployable from the given FileArchive.
     * @param fileArchive the file archive.
     * @return a file deployable.
     * @throws FileDeployableException when the file deployable
     *  could not be created.
     */
    public FileDeployable<?, ?> getFileDeployable(final IFileArchive fileArchive)
                                            throws FileDeployableException;

}
