/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.deploy.api.deployable.metadata;

import org.ow2.util.ee.deploy.api.deployable.IDeployable;

/**
 * Interface of a deployable metadata factory.
 * @param <E> deployable type
 * @param <Z> metadata type
 * @author Gael Lalire
 */
public interface IDeployableMetadataFactory<E extends IDeployable<E>, Z extends IDeployableMetadata<E>> {

    /**
     * Class suffix.
     */
    String CLASS_SUFFIX = ".class";

    /**
     * @param deployable the deployable
     * @return the deployable metadata
     * @throws DeployableMetadataException if metadata can not be created
     */
    Z createDeployableMetadata(E deployable) throws DeployableMetadataException;

    /**
     * @param deployable the deployable
     * @param classLoader a classloader to use if a class is not in archive
     * @return the deployable metadata
     * @throws DeployableMetadataException if metadata can not be created
     */
    Z createDeployableMetadata(E deployable, ClassLoader classLoader) throws DeployableMetadataException;

    /**
     * @return the class returned by creation of metadata (eg : EJB3DeployableMetadata.class)
     */
    Class<Z> getDeployableMetadataClass();

}
