/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.deploy.api.deployer;

import org.ow2.util.ee.deploy.api.deployable.IDeployable;

/**
 * Interface defining callbacks executed during deployment/undeployment events.
 * All types of {@IDeployable} are handled.
 * @author Francois Fornaciari
 */
public interface IDeployerManagerCallback {

    /**
     * Method called before deploying the given deployable.
     * @param deployable The deployable to deploy
     */
    void preDeploy(IDeployable<?> deployable);

    /**
     * Method called after having deployed the given deployable.
     * @param deployable The deployable to deploy
     */
    void postDeploy(IDeployable<?> deployable);

    /**
     * Method called before undeploying the given deployable.
     * @param deployable The deployable to undeploy
     */
    void preUndeploy(IDeployable<?> deployable);

    /**
     * Method called after having undeployed the given deployable.
     * @param deployable The deployable to undeploy
     */
    void postUndeploy(IDeployable<?> deployable);
}
