/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.deploy.impl.deployable;

import org.ow2.util.archive.api.IArchive;
import org.ow2.util.ee.deploy.api.deployable.OSGiDeployable;

/**
 * Implementation of the OSGi Deployable interface.
 * @author Florent BENOIT
 * @author Francois FORNACIARI
 */
public class OSGiDeployableImpl extends AbsDeployable<OSGiDeployable> implements OSGiDeployable {

    /**
     * True if the bundle must be started (default true).
     */
    private Boolean start = Boolean.TRUE;

    /**
     * True if the bundle must be a referenced JAR file (default false).
     */
    private Boolean reference = Boolean.FALSE;

    /**
     * The bundle start level.
     */
    private Integer startLevel = 1;

    /**
     * True if the bundle start operation is transient.
     * The persistent autostart setting of the bundle is not modified.
     */
    private Boolean startTransient = Boolean.TRUE;

    /**
     * Defines and create an OSGi deployable for the given archive.
     * @param archive the given archive.
     */
    public OSGiDeployableImpl(final IArchive archive) {
        super(archive);
    }

    /**
     * {@inheritDoc}
     */
    public void setStart(final Boolean start) {
        this.start = start;
    }

    /**
     * {@inheritDoc}
     */
    public Boolean isStart() {
        return start;
    }

    /**
     * {@inheritDoc}
     */
    public Boolean isReference() {
        return reference;
    }

    /**
     * {@inheritDoc}
     */
    public void setReference(final Boolean reference) {
        this.reference = reference;
    }

    /**
     * {@inheritDoc}
     */
    public Integer getStartLevel() {
        return startLevel;
    }

    /**
     * {@inheritDoc}
     */
    public void setStartLevel(final Integer startLevel) {
        this.startLevel = startLevel;
    }

    /**
     * {@inheritDoc}
     */
    public Boolean isStartTransient() {
        return startTransient;
    }

    /**
     * {@inheritDoc}
     */
    public void setStartTransient(final Boolean startTransient) {
        this.startTransient = startTransient;
    }

}
