/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.deploy.impl.deployer;

import org.ow2.util.ee.deploy.api.deployable.IDeployable;
import org.ow2.util.ee.deploy.api.deployer.DeployerException;
import org.ow2.util.ee.deploy.api.deployer.IDeployer;
import org.ow2.util.ee.deploy.api.report.IDeploymentReport;
import org.ow2.util.ee.deploy.impl.report.DeploymentReport;

import java.util.ArrayList;
import java.util.List;

/**
 * Abstract class that defines common methods to deploy a list of deployable.
 * @author Jeremy Cazaux
 */
public abstract class AbsDeployerList<T extends IDeployable<T>> implements IDeployer<T> {

    /**
     * {@inheritDoc}
     */
    public List<IDeploymentReport> deploy(final List<IDeployable<T>> deployables) {
        List<IDeploymentReport> deploymentReports = new ArrayList<IDeploymentReport>();

        for (IDeployable<T> deployable: deployables) {
            DeploymentReport deploymentReport = new DeploymentReport();
            deploymentReport.setDeployable(deployable);
            try {
                deploy(deployable);
                deploymentReport.setDeploymentOk(true);
            } catch (Exception e) {
                deploymentReport.setException(e);
                deploymentReport.setDeploymentOk(false);
            }
            deploymentReports.add(deploymentReport);
        }

        return deploymentReports;
    }

    /**
     * {@inheritDoc}
     */
    public List<IDeploymentReport> undeploy(final List<IDeployable<T>> deployables) {
        List<IDeploymentReport> deploymentReports = new ArrayList<IDeploymentReport>();

        for (IDeployable<T> deployable: deployables) {
            DeploymentReport deploymentReport = new DeploymentReport();
            deploymentReport.setDeployable(deployable);
            try {
                undeploy(deployable);
                deploymentReport.setDeploymentOk(true);
            } catch (DeployerException e) {
                deploymentReport.setException(e);
                deploymentReport.setDeploymentOk(false);
            }
            deploymentReports.add(deploymentReport);
        }

        return deploymentReports;
    }

    /**
     * {@inheritDoc}
     */
    public boolean supports(final List<IDeployable<?>> deployables) {

        for (IDeployable deployable: deployables) {
            if (!supports(deployable)) {
                return false;
            }
        }
        return true;
    }
}
