/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.deploy.impl.deployment.ear;

import java.util.LinkedList;
import java.util.List;

import org.ow2.util.ee.deploy.api.deployment.ear.ConnectorModule;
import org.ow2.util.ee.deploy.api.deployment.ear.EJBModule;
import org.ow2.util.ee.deploy.api.deployment.ear.IEARInfo;
import org.ow2.util.ee.deploy.api.deployment.ear.JavaModule;
import org.ow2.util.ee.deploy.api.deployment.ear.Module;
import org.ow2.util.ee.deploy.api.deployment.ear.WebModule;

/**
 * An EAR is a collection of Modules.
 * @author Florent Benoit
 */
public class EARInfoImpl implements IEARInfo {

    /**
     * Library directory.
     */
    private String libraryDirectory = DEFAULT_LIBRARY_FOLDER;

    /**
     * List of connector modules.
     */
    private List<ConnectorModule> connectorModules = null;

    /**
     * List of EJB modules.
     */
    private List<EJBModule> ejbModules = null;

    /**
     * List of Java modules.
     */
    private List<JavaModule> javaModules = null;

    /**
     * List of Web modules.
     */
    private List<WebModule> webModules = null;

    /**
     * Default constructor.
     */
    public EARInfoImpl() {
        // Use LinkedList to preserve the order
        this.connectorModules = new LinkedList<ConnectorModule>();
        this.ejbModules = new LinkedList<EJBModule>();
        this.javaModules = new LinkedList<JavaModule>();
        this.webModules = new LinkedList<WebModule>();
    }

    /**
     * @return list of modules.
     */
    public List<Module> getModules() {
        // List of all modules : concatenation
        List<Module> allModules = new LinkedList<Module>();

        // Add connectors
        for (ConnectorModule connectorModule : connectorModules) {
            allModules.add(connectorModule);
        }

        // Add EJB
        for (EJBModule ejbModule : ejbModules) {
            allModules.add(ejbModule);
        }

        // Add clients
        for (JavaModule javaModule : javaModules) {
            allModules.add(javaModule);
        }

        // Add Webs
        for (WebModule webModule : webModules) {
            allModules.add(webModule);
        }

        return allModules;
    }

    /**
     * @return list of Connector modules.
     */
    public List<ConnectorModule> getConnectors() {
        return connectorModules;
    }

    /**
     * @return list of EJB modules.
     */
    public List<EJBModule> getEJBs() {
        return ejbModules;
    }

    /**
     * Add the given EJB module to the list of EJB modules.
     * @param ejbModule the module to add
     */
    public void addEJBModule(final EJBModule ejbModule) {
        ejbModules.add(ejbModule);
    }

    /**
     * Add the given Web module to the list of Web modules.
     * @param webModule the module to add
     */
    public void addWebModule(final WebModule webModule) {
        webModules.add(webModule);
    }

    /**
     * Add the given Connector module to the list of Connector modules.
     * @param connectorModule the module to add
     */
    public void addConnectorModule(final ConnectorModule connectorModule) {
        connectorModules.add(connectorModule);
    }

    /**
     * Add the given Java module to the list of Java modules.
     * @param javaModule the module to add
     */
    public void addJavaModule(final JavaModule javaModule) {
        javaModules.add(javaModule);
    }

    /**
     * @return list of Client container modules.
     */
    public List<JavaModule> getClients() {
        return javaModules;
    }

    /**
     * @return list of Web modules.
     */
    public List<WebModule> getWebs() {
        return webModules;
    }

    /**
     * Sets the library-directory.
     * @param libraryDirectory the given library folder
     */
    public void setLibraryDirectory(final String libraryDirectory) {
        this.libraryDirectory = libraryDirectory;
    }

    /**
     * @return the library-directory.
     */
    public String getLibraryDirectory() {
        return libraryDirectory;
    }

}
