/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.deploy.impl.helper;

import org.osgi.framework.BundleContext;
import org.osgi.framework.InvalidSyntaxException;
import org.osgi.util.tracker.ServiceTracker;
import org.osgi.util.tracker.ServiceTrackerCustomizer;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;

/**
 * DeployerHelper tracker
 * @Jeremy Cazaux
 */
public class DeployableAnalyserTracker {

    /**
     * The service tracker
     */
    private ServiceTracker serviceTracker;

    /**
     * The logger
     */
    private static Log logger = LogFactory.getLog(DeployableHelperComponent.class);

    /**
     * The BundleContext
     */
    private BundleContext bundleContext;

    /**
     *  LDAP filter for OSGi ServiceTracker
     */
    public static String IDEPLOYABLE_ANALYSER_FILTER = "(&(objectClass=org.ow2.util.ee.deploy.api.helper.IDeployableAnalyser))";

    /**
     * Start the service tracker
     */
    public void start() {

        try {
            this.serviceTracker = new ServiceTracker(
                    bundleContext,
                    bundleContext.createFilter(IDEPLOYABLE_ANALYSER_FILTER),
                    (ServiceTrackerCustomizer) null
            );
        } catch (InvalidSyntaxException e) {
            logger.error("Cannot create filter .", e);
        }
        this.serviceTracker.open();
    }


    /**
     * Close the service tracker
     */
    public void stop() {
        this.serviceTracker.close();
    }

    /**
     * Default constructor
     */
    public DeployableAnalyserTracker(final BundleContext bundleContext) {
        this.bundleContext = bundleContext;
    }

    /**
     * @return IDeployableAnalyser services
     */
    public Object[] getServices() {
        return this.serviceTracker.getServices();
    }

}
