/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.deploy.impl.helper;

import org.ow2.util.asm.AnnotationVisitor;
import org.ow2.util.asm.commons.EmptyVisitor;
import org.ow2.util.ee.deploy.api.deployable.ArchiveType;

/**
 * This visitor try to find the type of an archive.
 * @author Florent Benoit
 */
public class DeployableDetectVisitor extends EmptyVisitor {

    /**
     * Type of the archive.
     */
    private ArchiveType archiveType = null;

    /**
     * MDB annotation.
     */
    private static final String MDB_ANNOTATION = "Ljavax/ejb/MessageDriven;";

    /**
     * Stateless annotation.
     */
    private static final String STATELESS_ANNOTATION = "Ljavax/ejb/Stateless;";

    /**
     * Stateful annotation.
     */
    private static final String STATEFUL_ANNOTATION = "Ljavax/ejb/Stateful;";

    /**
     * Singleton annotation.
     */
    private static final String SINGLETON_ANNOTATION = "Ljavax/ejb/Singleton;";


    /**
     * Singleton annotation.
     */
    private static final String MANAGED_BEAN_ANNOTATION = "Ljavax/annotation/ManagedBean;";

    /**
     * Visits an annotation of the class.
     * @param desc the class descriptor of the annotation class.
     * @param visible <tt>true</tt> if the annotation is visible at runtime.
     * @return a non null visitor to visit the annotation values.
     */
    @Override
    public AnnotationVisitor visitAnnotation(final String desc, final boolean visible) {
        // update value only if it is not yet detected
        if (archiveType == null) {
            if (desc.equals(MDB_ANNOTATION) || desc.equals(STATEFUL_ANNOTATION) || desc.equals(STATELESS_ANNOTATION)
                    || desc.equals(SINGLETON_ANNOTATION) || desc.equals(MANAGED_BEAN_ANNOTATION)) {
                this.archiveType = ArchiveType.EJB3JAR;
            }
        }

        return this;
    }

    /**
     * Gets the archive type.
     * @return the archive type.
     */
    public ArchiveType getArchiveType() {
        return archiveType;
    }

}
