/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.deploy.impl.helper;

import org.ow2.util.ee.deploy.api.helper.*;
import org.ow2.util.archive.api.IArchive;
import org.ow2.util.ee.deploy.api.deployable.IDeployable;
import org.ow2.util.ee.deploy.api.helper.DeployableHelperException;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;

import java.util.ArrayList;
import java.util.List;

/**
 * Component which analyze an archive and build the associated Deployable object.
 * @author Jeremy Cazaux
 */
public class DeployableHelperComponent implements IDeployableHelper {

    /**
     * List of deployableAnalysers
     */
    private List<IDeployableAnalyser> deployableAnalysers;

    /**
     * The logger
     */
    private static Log logger = LogFactory.getLog(DeployableHelperComponent.class);

    /**
     * DeployableAnalyser tracker
     */
    private DeployableAnalyserTracker deployableAnalyserTracker;

    /**
     * Default constructor
     */
    public DeployableHelperComponent(final DeployableAnalyserTracker deployableAnalyserTracker) {
        this.deployableAnalysers = new ArrayList<IDeployableAnalyser>();
        this.deployableAnalyserTracker = deployableAnalyserTracker;
    }

    /*
    * Gets the Deployable object for the given URL.
    * @param archive the given archive
    * @return the Deployable object
    * @throws DeployableHelperException if the analyze fails
    */
    public IDeployable<?> getDeployable(final IArchive archive) throws DeployableHelperException {
        return getDeployable(archive, true);
    }

    /**
     * Gets the Deployable object for the given URL.
     * @param archive the given archive
     * @param isOSGiEnabled if OSGi Deployable can be used
     * @return the Deployable object
     */
    public IDeployable<?> getDeployable(final IArchive archive, boolean isOSGiEnabled) throws DeployableHelperException {

        IDeployable deployable = null;

        Object[] deployableAnalysers = this.deployableAnalyserTracker.getServices();

        if (deployableAnalysers != null) {

            for (Object deployableAnalyser: deployableAnalysers) {

                deployable = ((IDeployableAnalyser) deployableAnalyser).analyze(archive);

                if (deployable != null) {
                    return deployable;
                }
            }
        }

        return DeployableHelper.getDeployable(archive, isOSGiEnabled);
    }
}