/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.deploy.impl.osgi;

import static org.mockito.Matchers.anyString;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;

import java.io.File;

import org.osgi.framework.BundleContext;
import org.osgi.framework.BundleException;
import org.ow2.util.archive.api.IArchive;
import org.ow2.util.ee.deploy.api.deployer.DeployerException;
import org.ow2.util.ee.deploy.impl.deployable.OSGiDeployableImpl;
import org.testng.annotations.Test;

public class OSGiDeployerTestCase {

    @Test
    public void testDuplicateBundleExceptionIsIgnored() throws Exception {

        // Mocks
        BundleContext bundleContext = mock(BundleContext.class);
        OSGiDeployableImpl deployable = mock(OSGiDeployableImpl.class);
        IArchive archive = mock(IArchive.class);

        // The mock URL
        File userDir = new File(System.getProperty("user.dir"));

        // Behaviors
        when(deployable.getArchive()).thenReturn(archive);
        when(archive.getURL()).thenReturn(userDir.toURI().toURL());
        // When installbundle is called, always return a Bundle Exception
        BundleException be = new BundleException("Expected", BundleException.DUPLICATE_BUNDLE_ERROR);
        when(bundleContext.installBundle(anyString())).thenThrow(be);

        // Init the tested type
        OSGiDeployer deployer = new OSGiDeployer(bundleContext);

        // Try the deployment process
        deployer.deploy(deployable);
    }

    @Test(expectedExceptions = DeployerException.class)
    public void testOtherBundleExceptionAreWrapped() throws Exception {

        // Mocks
        BundleContext bundleContext = mock(BundleContext.class);
        OSGiDeployableImpl deployable = mock(OSGiDeployableImpl.class);
        IArchive archive = mock(IArchive.class);

        // The mock URL
        File userDir = new File(System.getProperty("user.dir"));

        // Behaviors
        when(deployable.getArchive()).thenReturn(archive);
        when(archive.getURL()).thenReturn(userDir.toURI().toURL());
        // When installbundle is called, always return a Bundle Exception
        BundleException be = new BundleException("Expected", BundleException.ACTIVATOR_ERROR);
        when(bundleContext.installBundle(anyString())).thenThrow(be);

        // Init the tested type
        OSGiDeployer deployer = new OSGiDeployer(bundleContext);

        // Try the deployment process
        deployer.deploy(deployable);
    }
}

